export * from './service.ts';
import { type QueuePublishParams, type QueuePublishResult, type QueueCreateParams, type QueueCreateResult } from './service.ts';
import { type Logger } from '@agentuity/client';
import { z } from 'zod';
export declare const QueueClientOptionsSchema: z.ZodObject<{
    apiKey: z.ZodOptional<z.ZodString>;
    url: z.ZodOptional<z.ZodString>;
    orgId: z.ZodOptional<z.ZodString>;
    logger: z.ZodOptional<z.ZodCustom<Logger, Logger>>;
}, z.core.$strip>;
export type QueueClientOptions = z.infer<typeof QueueClientOptionsSchema>;
export declare class QueueClient {
    #private;
    constructor(options?: QueueClientOptions);
    publish(queueName: string, payload: string | object, params?: QueuePublishParams): Promise<QueuePublishResult>;
    createQueue(queueName: string, params?: QueueCreateParams): Promise<QueueCreateResult>;
    deleteQueue(queueName: string): Promise<void>;
}
//# sourceMappingURL=index.d.ts.map